==> haskell-attoparsec-0.14.4-174.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-attoparsec-z-attoparsec-internal
version:              0.14.4
package-name:         attoparsec
lib-name:             attoparsec-internal
id:
    attoparsec-0.14.4-2VlccXlunsHKsfQCy9YyEf-attoparsec-internal

key:
    attoparsec-0.14.4-2VlccXlunsHKsfQCy9YyEf-attoparsec-internal

license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  8c529154f55e60c42fd58e52a7d2e77c
exposed-modules:
    Data.Attoparsec.ByteString.Buffer
    Data.Attoparsec.ByteString.FastSet Data.Attoparsec.Internal.Compat
    Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
    Data.Attoparsec.Text.FastSet

import-dirs:          /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:
    HSattoparsec-0.14.4-2VlccXlunsHKsfQCy9YyEf-attoparsec-internal

depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec
version:              0.14.4
visibility:           public
id:                   attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm
key:                  attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  db0acfc01f22c8aaad55e86cb94de2b1
exposed:              True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto

hidden-modules:
    Data.Attoparsec.ByteString.Internal Data.Attoparsec.Text.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:         HSattoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm
depends:
    array-0.5.6.0
    attoparsec-0.14.4-2VlccXlunsHKsfQCy9YyEf-attoparsec-internal
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    ghc-prim-0.10.0 scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV
    text-2.0.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-0.14.4-175-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-attoparsec-z-attoparsec-internal
version:              0.14.4
package-name:         attoparsec
lib-name:             attoparsec-internal
id:                   attoparsec-0.14.4-x4N5aEOqXSF8DbiVDoqth-attoparsec-internal
key:                  attoparsec-0.14.4-x4N5aEOqXSF8DbiVDoqth-attoparsec-internal
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  13a1fe98bcd8059d4e6b36345cebe035
exposed-modules:
    Data.Attoparsec.ByteString.Buffer
    Data.Attoparsec.ByteString.FastSet Data.Attoparsec.Internal.Compat
    Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
    Data.Attoparsec.Text.FastSet

import-dirs:          /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:
    HSattoparsec-0.14.4-x4N5aEOqXSF8DbiVDoqth-attoparsec-internal

depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec
version:              0.14.4
visibility:           public
id:                   attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE
key:                  attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  9cdb6084824cfb58302a5f27a6b6ffcd
exposed:              True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto

hidden-modules:
    Data.Attoparsec.ByteString.Internal Data.Attoparsec.Text.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:         HSattoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE
depends:
    array-0.5.6.0
    attoparsec-0.14.4-x4N5aEOqXSF8DbiVDoqth-attoparsec-internal
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    ghc-prim-0.10.0 scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW
    text-2.0.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
